@@ -79,12 +79,19 @@ class GitRepo:
                     branch = self.repo.create_head(version, origin.refs[version])
                     branch.set_tracking_branch(origin.refs[version])
                     branch.checkout()
-                elif version in self.repo.tags:
+                elif origin.fetch("--tags") and version in self.repo.tags:
                     git = self.repo.git
                     git.checkout(version, b=version)         # create a new branch, name same as tag
+                else:
+                    # commit id
+                    git = self.repo.git
+                    git.checkout(version)
             else:
-                origin.pull(version)
-                self.repo.heads[version].set_tracking_branch(origin.refs[version])
+                if version in origin.refs:
+                    origin.pull(version)
+                    self.repo.heads[version].set_tracking_branch(origin.refs[version])
+                else:
+                    origin.pull()
 
         except Exception as ex:
             info = str(ex)
@@ -166,24 +173,48 @@ class GitRepo:
         return self.repo.tags
 
     def CheckoutBranch(self, version):
-        self.pull(version)
-        git = self.repo.git
+        if not version:
+            return
         try:
+            git = self.repo.git
             origin = self.repo.remote()
-            if version not in origin.refs:
-                git.checkout('HEAD', b=version)
+            if version not in self.repo.heads:
+                if version not in origin.refs:
+                    origin.fetch()
+                if version in origin.refs:
+                    branch = self.repo.create_head(version, origin.refs[version])
+                    branch.set_tracking_branch(origin.refs[version])
+                    branch.checkout()
+                elif origin.fetch("--tags") and version in self.repo.tags:
+                    git.checkout(version, b=version)         # create a new branch, name same as tag
+                else:
+                    try:
+                        # put_string("Checkout commit id: %s" % version)
+                        git.checkout(version, b=version)    # commit_id
+                    except:
+                        put_string("Can't find version/commit: %s, Checkout with HEAD." % version, level='warning')
+                        git.checkout('HEAD')
             else:
                 git.checkout(version)
         except Exception as ex:
+            if str(ex).find("already exists.") > 0:
+                put_string("Branch: %s already exists." % version, level='warning')
+                return
             put_string(str(ex), level='error')
-            pass
 
     def sync(self):
         name = os.path.basename(self.path)
         if self.repo.is_dirty(untracked_files=False):
             put_string("There are modified files in %s, please commit or stash first." % name, level='warning')
             return
-        self.pull()
+        try:
+            git = self.repo.git
+            ret = git.pull()
+            if ret.find("Already up to date") < 0:
+                put_string("%s:" % name, color='blue')
+                put_string("%s" % ret, color='cyan')
+        except Exception:
+            pass
 
     def status(self):
         name = os.path.basename(self.path)
@@ -203,7 +234,7 @@ class GitRepo:
 
     def gitlog(self):
         name = os.path.basename(self.path)
-        put_string("%s:" % name, color='magenta')
+        put_string("* %s:" % name, color='magenta')
         headcommit = self.repo.head.commit
         put_string("    commit %s" % headcommit.hexsha, color='orange')
         put_string("    Author: %s <%s>" % (headcommit.author.name, headcommit.author.email))
