@@ -257,6 +257,7 @@ class Package(object):
         self.license = ''
         self.homepage = ''
         self.depends = {}
+        self.depends_forward = {}
         self.sdk_chip = {}
         self.build_config = build_config({})
         self.defconfig = {}
@@ -362,14 +363,13 @@ class Package(object):
 ## 第一部分： 基础信息
 {name}{version}{description}{type}{tag}{keywords}{homepage}{author}{license}
 ## 第二部分：依赖信息
-#           指定该组件依赖的组件及版本，版本支持条件比较，支持：>=v1.0, >v1.0, ==v1.0, <=v1.0, <v1.0, v1.0
-#           未指定条件时，默认为 ==，如 v1.0 与 ==v1.0
+#           指定该组件依赖的组件及版本
 # sdk_chip:                                # <可选项> 该组件依赖sdk组件，合理的依赖才能保证组件能编译、使用
-#   - sdk_chip_csky_dummy: v7.4.y
-#   - sdk_chip_riscv_dummy: v7.4.y
+#   - sdk_chip_csky_dummy: v7.4.0
+#   - sdk_chip_riscv_dummy: v7.4.0
 # depends:                                 # <可选项> 该组件依赖其他的组件，合理的依赖才能保证组件能编译、使用
-#   - minilibc: v7.2.0
-#   - aos: >=v7.2.0
+#   - minilibc: v7.4.0
+#   - aos: v7.4.0
 {sdk_chip}{depends}{hw_info}
 ## 第四部分：编译连接信息
 # build_config:                            # <可选项> 编译配置项
@@ -418,6 +418,7 @@ class Package(object):
                 'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common, sdk'),
             sdk_chip=self.sdk_chip_out(),
             depends=self.depends_out(),
+            # depends_forward=self.depends_forward_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
             export=self.install_out('export', self.export),
@@ -490,6 +491,20 @@ class Package(object):
 
         return text
 
+    def depends_forward_out(self):
+        text = ''
+        if len(self.depends_forward) > 0:
+            text = 'depends_forward:\n'
+            for d in self.depends_forward:
+                for k, v in d.items():
+                    if ">=" in v:
+                        text += '  - {}: "{}"\n'.format(k, v)
+                    else:
+                        text += '  - {}: {}\n'.format(k, v)
+                    break
+
+        return text
+
     def sdk_chip_out(self):
         text = ''
         if len(self.sdk_chip) > 0:
