@@ -269,8 +269,13 @@ class Solution:
         for component in self.components:
             if len(component.source_files) > 0 and component.name not in self.libs:
                 self.libs.append(component.name)
-                self.depend_libs.append(os.path.join(
-                    self.lib_path, 'lib' + component.name + '.a'))
+                # if component.name is start with lib, scons will not add prefix: lib
+                if component.name.startswith('lib'):
+                    self.depend_libs.append(os.path.join(
+                        self.lib_path, component.name + '.a'))
+                else:
+                    self.depend_libs.append(os.path.join(
+                        self.lib_path, 'lib' + component.name + '.a'))
 
             component.variable_convert(self.variables)
 
@@ -414,6 +419,8 @@ def riscv_cpu_id(cpu):
         return 'rv32_16gpr'
     elif a == 'e906':
         return 'rv32_32gpr'
+    elif a == 'e907fp':
+        return 'rv32f_32gpr'
     elif a == 'e906f':
         return 'rv32f_32gpr'
     elif a == 'e906fd':
