@@ -19,7 +19,7 @@ import os
 all_commands = {}
 
 
-exclude_cmd = ['checkout', 'uninstall', 'sdk', 'br2tag', 'protect']   # release
+exclude_cmd = ['uninstall', 'sdk', 'br2tag', 'protect', 'users']   # release
 # exclude_cmd = ['uninstall', 'sdk']                                      # develop
 
 my_dir = os.path.dirname(__file__)
