@@ -120,7 +120,7 @@ temp = '''<?xml version="1.0" encoding="UTF-8"?>
   <Description>{description}</Description>
   <MonitorProgress>
     <FlashOperate>230</FlashOperate>
-    <DebugLaunch>42</DebugLaunch>
+    <DebugLaunch>118</DebugLaunch>
   </MonitorProgress>
   <Chips>
     <Chip ID="{chip_name}" Version="{chip_version}" IsBasic="false"/>
@@ -134,7 +134,7 @@ temp = '''<?xml version="1.0" encoding="UTF-8"?>
   <DebugSessions>
     <watchExpressions/>
     <memoryExpressions>;;;</memoryExpressions>
-    <statistics>;;MHZ</statistics>
+    <statistics>;;MHZ;</statistics>
     <peripheralTabs/>
     <WatchDisplayFormat>0</WatchDisplayFormat>
     <LocalDisplayFormat>0</LocalDisplayFormat>
@@ -218,7 +218,7 @@ temp = '''<?xml version="1.0" encoding="UTF-8"?>
         <Preprocessor>no</Preprocessor>
         <Disassmeble>yes</Disassmeble>
         <CallGraph>no</CallGraph>
-        <Map>no</Map>
+        <Map>yes</Map>
       </Output>
       <User>
         <BeforeCompile>
@@ -269,12 +269,12 @@ temp = '''<?xml version="1.0" encoding="UTF-8"?>
         <LinkType/>
       </Linker>
       <Debug>
-        <LoadApplicationAtStartup>no</LoadApplicationAtStartup>
+        <LoadApplicationAtStartup>yes</LoadApplicationAtStartup>
         <Connector>ICE</Connector>
-        <StopAt>no</StopAt>
+        <StopAt>yes</StopAt>
         <StopAtText>main</StopAtText>
         <InitFile>$(ProjectPath)/script/gdbinit</InitFile>
-        <AutoRun>no</AutoRun>
+        <AutoRun>yes</AutoRun>
         <ResetType>Hard Reset</ResetType>
         <SoftResetVal/>
         <ResetAfterLoad>no</ResetAfterLoad>
