@@ -179,6 +179,13 @@ class YoC:
         else:
             git.pull(self.conf.branch, None)
 
+    def sync_manifest(self):
+        manifest_path = os.path.join(self.yoc_path, ".repo")
+        if os.path.exists(manifest_path):
+            repo_url = self.conf.repo
+            git = GitRepo(manifest_path, repo_url)
+            git.pull(self.conf.branch, None)
+
     def manifest_yaml_parse(self, filename=None):
         if not filename:
             filename = os.path.join(self.yoc_path, ".repo/default.yaml")
